@@ -329,3 +329,54 @@ mlflow_transition_model_version_stage <- function(name, version, stage,
 
   return(response$model_version)
 }
+
+#' Set Model version tag
+#'
+#' Set a tag for the model version.
+#' When stage is set, tag will be set for latest model version of the stage.
+#' Setting both version and stage parameter will result in error.
+#'
+#' @param name Registered model name.
+#' @param version Registered model version.
+#' @param key Tag key to log. key is required.
+#' @param value Tag value to log. value is required.
+#' @param stage Registered model stage.
+#' @template roxlate-client
+#' @export
+mlflow_set_model_version_tag <- function(name, version = NULL, key = NULL, value = NULL, stage = NULL, client = NULL) {
+    if (!is.null(version) && !is.null(stage)) {
+        stop("version and stage cannot be set together",
+            call. = FALSE
+        )
+    }
+
+    if (is.null(version) && is.null(stage)) {
+        stop("version or stage must be set",
+            call. = FALSE
+        )
+    }
+
+    client <- resolve_client(client)
+
+    if (!is.null(stage)) {
+        latest_versions <- mlflow_get_latest_versions(name = name, stages = list(stage))
+        if (is.null(latest_versions)) {
+            stop(sprintf("Could not find any model version for %s stage", stage),
+                call. = FALSE
+            )
+        }
+        version <- latest_versions[[1]]$version
+    }
+
+    response <- mlflow_rest(
+        "model-versions", "set-tag",
+        client = client, verb = "POST",
+        data = list(
+            name = name,
+            version = version,
+            key = key,
+            value = value
+        )
+    )
+    invisible(NULL)
+}
